job "ipdvr" {
  region = "global"
  datacenters = ["dc1"]

  type = "service"

  group "sabnzbd" {
    network {
      mode = "bridge"

      port "main" {
        host_network = "wesher"
        to = 8080
      }
    }

    volume "sabnzbd-config" {
      type = "host"
      read_only = false
      source = "sabnzbd-config"
    }

    volume "media-downloads" {
      type = "host"
      read_only = false
      source = "media-downloads"
    }

    service {
      name = "sabnzbd"
      provider = "nomad"
      port = "main"

      tags = [
        "traefik.enable=true",
        "traefik.http.routers.sabnzbd.entryPoints=websecure",
      ]
    }

    task "sabnzbd" {
      driver = "docker"

      config {
        image = "linuxserver/sabnzbd"
        ports = ["main"]
      }

      env = {
        "PGID" = 100
        "PUID" = 1001
        "TZ" = "America/Los_Angeles"
      }

      volume_mount {
        volume = "sabnzbd-config"
        destination = "/config"
        read_only = false
      }

      volume_mount {
        volume = "media-downloads"
        destination = "/downloads"
        read_only = false
      }

      resources {
        cpu = 400
        memory = 500
        memory_max = 800
      }
    }
  }

  group "nzbget" {
    network {
      mode = "bridge"
      port "main" {
        host_network = "wesher"
        static = 6789
      }
    }

    volume "nzbget-config" {
      type = "host"
      read_only = false
      source = "nzbget-config"
    }

    volume "media-downloads" {
      type = "host"
      read_only = false
      source = "media-downloads"
    }

    service {
      name = "nzbget"
      provider = "nomad"
      port = "main"

      tags = [
        "traefik.enable=true",
        "traefik.http.routers.nzbget.entryPoints=websecure",
      ]
    }

    task "nzbget" {
      driver = "docker"

      config {
        image = "linuxserver/nzbget"
        ports = ["main"]
      }

      env = {
        "PGID" = 100
        "PUID" = 1001
        "TZ" = "America/Los_Angeles"
      }

      volume_mount {
        volume = "nzbget-config"
        destination = "/config"
        read_only = false
      }

      volume_mount {
        volume = "media-downloads"
        destination = "/downloads"
        read_only = false
      }

      resources {
        cpu = 200
        memory = 300
        memory_max = 500
      }
    }
  }


  group "sonarr" {
    network {
      mode = "bridge"
      port "main" {
        host_network = "wesher"
        to = 8989
      }
    }

    volume "sonarr-data" {
      type = "host"
      read_only = false
      source = "sonarr-data"
    }

    volume "media-write" {
      type = "host"
      read_only = false
      source = "media-write"
    }

    service {
      name = "sonarr"
      provider = "nomad"
      port = "main"

      tags = [
        "traefik.enable=true",
        "traefik.http.routers.sonarr.entryPoints=websecure",
      ]
    }

    task "sonarr" {
      driver = "docker"

      config {
        image = "linuxserver/sonarr"
        ports = ["main"]
      }

      env = {
        "PGID" = 100
        "PUID" = 1001
        "TZ" = "America/Los_Angeles"
      }

      volume_mount {
        volume = "sonarr-data"
        destination = "/config"
        read_only = false
      }

      volume_mount {
        volume = "media-write"
        destination = "/media"
        read_only = false
      }

      resources {
        cpu = 100
        memory = 450
        memory_max = 700
      }
    }
  }
}
